@@ -1,5 +1,7 @@
 from gtts import gTTS
 from enum import Enum
+
+# TODO: Move this to enums.py (?)
 class TLD(Enum):
     SPANISH_MEXICO = 'com.mx'
     SPANISH_SPAIN = 'es'
@@ -7,6 +9,7 @@ class TLD(Enum):
 
 class Language(Enum):
     SPANISH = 'es'
+    ENGLISH = 'en'
 
 def narrate(text,  language: Language = Language.SPANISH, tld: TLD = TLD.SPANISH_SPAIN, output_filename = None):
     """
