@@ -1,9 +1,7 @@
+from yta_general_utils.downloader.image import download_image
+from yta_general_utils.image.size import resize_without_scaling
 from openai import OpenAI
-from dotenv import load_dotenv
-from yta_general_utils.file_downloader import download_image
-from yta_general_utils.image_processor import resize_without_scaling
 
-load_dotenv()
 
 # TODO: Is this actually useful? I think it could be removed...
 
